% =========================================================
% Master file for the example "Optimal Transmission Design"
% =========================================================



% #####################################################################################################################

clear all
close all
clc
warning off

% #####################################################################################################################

% Global variables
% ----------------

    % Simulation
    global t
    global N_sim    
    global w_CE T_CE
    global gear_result 
    global V_liter 
    global first_gear second_gear third_gear fourth_gear fifth_gear
    
    % Combustion Engine map
    global eta_CE_map
    global w_CE_row
    global T_CE_col
    global w_CE_max
    global T_CE_max    
       
% Initialization of the optimization routine
% ------------------------------------------
    gear_result = [];
    i_guess = [15.1740; 8.3380; 5.3780; 3.9370; 2.7480];          
    
% Optimization routine
% --------------------
    disp('Optimization started...')
    disp(' ')
    i_opt = fminsearch('OptiGear', i_guess)
    disp(' ')
    disp('... optimization finished!')    
  
% Plot results
% ------------
    disp(' ')
    disp('Hit a key to plot results:')

    pause
    clc

    % Gear ratios
    fig = figure;
    set(fig,'NumberTitle', 'off')
    set(fig,'Name', 'Optimized gear ratios')

        plot(gear_result)
        xlabel('Iterations')
        ylabel('Gear ratios [-]')
        title('Variations of the gear ratios during the optimization')
     
    % Combustion engine
    fig = figure;
    set(fig,'NumberTitle', 'off')
    set(fig,'Name', 'Combustion Engine')

        val_vec=[ 0.33 0.32 0.3 0.275 0.2  0.1];
        cs=contour(w_CE_row, T_CE_col, eta_CE_map, val_vec);
        clabel(cs)
        title('Combustion Engine map')
        xlabel('\omega_{CE} [rad/s]')
        ylabel('T_{CE} [Nm]')
        hold on
        plot(w_CE_max, T_CE_max)
        plot(w_CE, T_CE, 'o')
        hold off
        
% #####################################################################################################################
